@@ -33,77 +33,32 @@
 #include <vector>
 #include <list>
 #include <array>
-#ifdef __gnu_linux__
-#include <libgen.h>
-#include <unistd.h>
-#endif
+#include <iomanip>
+#include <inttypes.h>
+#include <spdlog/spdlog.h>
+#include <imgui.h>
 
+#include "mesa/util/macros.h" // defines "restrict" for vk_util.h
+#include "mesa/util/os_socket.h"
 #include <vulkan/vulkan.h>
 #include <vulkan/vk_layer.h>
-
-#include "imgui.h"
+#include <vulkan/vk_util.h>
+#include "vk_enum_to_str.h"
 
 #include "overlay.h"
-#include "font_default.h"
-
-// #include "util/debug.h"
-#include <inttypes.h>
-#include "mesa/util/macros.h"
-#include "mesa/util/os_time.h"
-#include "mesa/util/os_socket.h"
-
-#include "vk_enum_to_str.h"
-#include <vulkan/vk_util.h>
-
-#include "string_utils.h"
-#include "file_utils.h"
-#include "gpu.h"
-#include "logging.h"
-#include "cpu.h"
-#include "memory.h"
 #include "notify.h"
 #include "blacklist.h"
 #include "pci_ids.h"
-#include "timing.hpp"
 
-string gpuString,wineVersion,wineProcess;
 float offset_x, offset_y, hudSpacing;
 int hudFirstRow, hudSecondRow;
 VkPhysicalDeviceDriverProperties driverProps = {};
-int32_t deviceID;
 
+#if !defined(_WIN32)
 namespace MangoHud { namespace GL {
    extern swapchain_stats sw_stats;
 }}
-
-/* Mapped from VkInstace/VkPhysicalDevice */
-struct instance_data {
-   struct vk_instance_dispatch_table vtable;
-   VkInstance instance;
-   struct overlay_params params;
-   uint32_t api_version;
-   string engineName, engineVersion;
-   enum EngineTypes engine;
-   notify_thread notifier;
-};
-
-/* Mapped from VkDevice */
-struct queue_data;
-struct device_data {
-   struct instance_data *instance;
-
-   PFN_vkSetDeviceLoaderData set_device_loader_data;
-
-   struct vk_device_dispatch_table vtable;
-   VkPhysicalDevice physical_device;
-   VkDevice device;
-
-   VkPhysicalDeviceProperties properties;
-
-   struct queue_data *graphic_queue;
-
-   std::vector<struct queue_data *> queues;
-};
+#endif
 
 /* Mapped from VkCommandBuffer */
 struct queue_data;
@@ -218,16 +173,13 @@ static void unmap_object(uint64_t obj)
    do { \
       VkResult __result = (expr); \
       if (__result != VK_SUCCESS) { \
-         fprintf(stderr, "'%s' line %i failed with %s\n", \
+         SPDLOG_ERROR("'{}' line {} failed with {}", \
                  #expr, __LINE__, vk_Result_to_str(__result)); \
       } \
    } while (0)
 
 /**/
 
-#define CHAR_CELSIUS    "\xe2\x84\x83"
-#define CHAR_FAHRENHEIT "\xe2\x84\x89"
-
 static void shutdown_swapchain_font(struct swapchain_data*);
 
 static VkLayerInstanceCreateInfo *get_instance_chain_info(const VkInstanceCreateInfo *pCreateInfo,
@@ -462,257 +414,18 @@ struct overlay_draw *get_overlay_draw(struct swapchain_data *data)
    return draw;
 }
 
-void init_cpu_stats(overlay_params& params)
-{
-#ifdef __gnu_linux__
-   auto& enabled = params.enabled;
-   enabled[OVERLAY_PARAM_ENABLED_cpu_stats] = cpuStats.Init()
-                           && enabled[OVERLAY_PARAM_ENABLED_cpu_stats];
-   enabled[OVERLAY_PARAM_ENABLED_cpu_temp] = cpuStats.GetCpuFile()
-                           && enabled[OVERLAY_PARAM_ENABLED_cpu_temp];
-   enabled[OVERLAY_PARAM_ENABLED_cpu_power] = cpuStats.InitCpuPowerData()
-                           && enabled[OVERLAY_PARAM_ENABLED_cpu_power];
-#endif
-}
-
-struct PCI_BUS {
-   int domain;
-   int bus;
-   int slot;
-   int func;
-};
-
-void init_gpu_stats(uint32_t& vendorID, overlay_params& params)
-{
-   //if (!params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats])
-   //   return;
-
-   PCI_BUS pci;
-   bool pci_bus_parsed = false;
-   const char *pci_dev = nullptr;
-   if (!params.pci_dev.empty())
-      pci_dev = params.pci_dev.c_str();
-
-   // for now just checks if pci bus parses correctly, if at all necessary
-   if (pci_dev) {
-      if (sscanf(pci_dev, "%04x:%02x:%02x.%x",
-               &pci.domain, &pci.bus,
-               &pci.slot, &pci.func) == 4) {
-         pci_bus_parsed = true;
-         // reformat back to sysfs file name's and nvml's expected format
-         // so config file param's value format doesn't have to be as strict
-         std::stringstream ss;
-         ss << std::hex
-            << std::setw(4) << std::setfill('0') << pci.domain << ":"
-            << std::setw(2) << pci.bus << ":"
-            << std::setw(2) << pci.slot << "."
-            << std::setw(1) << pci.func;
-         params.pci_dev = ss.str();
-         pci_dev = params.pci_dev.c_str();
-#ifndef NDEBUG
-         std::cerr << "MANGOHUD: PCI device ID: '" << pci_dev << "'\n";
-#endif
-      } else {
-         std::cerr << "MANGOHUD: Failed to parse PCI device ID: '" << pci_dev << "'\n";
-         std::cerr << "MANGOHUD: Specify it as 'domain:bus:slot.func'\n";
-      }
-   }
-
-   // NVIDIA or Intel but maybe has Optimus
-   if (vendorID == 0x8086
-      || vendorID == 0x10de) {
-
-      if(checkNvidia(pci_dev))
-         vendorID = 0x10de;
-      else
-         params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats] = false;
-   }
-
-#ifdef __gnu_linux__
-   if (vendorID == 0x8086 || vendorID == 0x1002
-       || gpu.find("Radeon") != std::string::npos
-       || gpu.find("AMD") != std::string::npos) {
-      string path;
-      string drm = "/sys/class/drm/";
-
-      auto dirs = ls(drm.c_str(), "card");
-      for (auto& dir : dirs) {
-         path = drm + dir;
-
-#ifndef NDEBUG
-         std::cerr << "amdgpu path check: " << path << "/device/vendor" << std::endl;
-#endif
-         string device = read_line(path + "/device/device");
-         deviceID = strtol(device.c_str(), NULL, 16);
-         string line = read_line(path + "/device/vendor");
-         trim(line);
-         if (line != "0x1002" || !file_exists(path + "/device/gpu_busy_percent"))
-            continue;
-
-         path += "/device";
-         if (pci_bus_parsed && pci_dev) {
-            string pci_device = read_symlink(path.c_str());
-#ifndef NDEBUG
-            std::cerr << "PCI device symlink: " << pci_device << "\n";
-#endif
-            if (!ends_with(pci_device, pci_dev)) {
-               std::cerr << "MANGOHUD: skipping GPU, no PCI ID match\n";
-               continue;
-            }
-         }
-
-#ifndef NDEBUG
-           std::cerr << "using amdgpu path: " << path << std::endl;
-#endif
-
-         if (!amdgpu.busy)
-            amdgpu.busy = fopen((path + "/gpu_busy_percent").c_str(), "r");
-         if (!amdgpu.vram_total)
-            amdgpu.vram_total = fopen((path + "/mem_info_vram_total").c_str(), "r");
-         if (!amdgpu.vram_used)
-            amdgpu.vram_used = fopen((path + "/mem_info_vram_used").c_str(), "r");
-
-         path += "/hwmon/";
-         string tempFolder;
-         if (find_folder(path, "hwmon", tempFolder)) {
-            if (!amdgpu.core_clock)
-               amdgpu.core_clock = fopen((path + tempFolder + "/freq1_input").c_str(), "r");
-            if (!amdgpu.memory_clock)
-               amdgpu.memory_clock = fopen((path + tempFolder + "/freq2_input").c_str(), "r");
-            if (!amdgpu.temp)
-               amdgpu.temp = fopen((path + tempFolder + "/temp1_input").c_str(), "r");
-            if (!amdgpu.power_usage)
-               amdgpu.power_usage = fopen((path + tempFolder + "/power1_average").c_str(), "r");
-
-            vendorID = 0x1002;
-            break;
-         }
-      }
-
-      // don't bother then
-      if (!amdgpu.busy && !amdgpu.temp && !amdgpu.vram_total && !amdgpu.vram_used) {
-         params.enabled[OVERLAY_PARAM_ENABLED_gpu_stats] = false;
-      }
-   }
-#endif
-   if (!params.permit_upload)
-      printf("MANGOHUD: Uploading is disabled (permit_upload = 0)\n");
-}
-
-void init_system_info(){
-   #ifdef __gnu_linux__
-      const char* ld_preload = getenv("LD_PRELOAD");
-      if (ld_preload)
-         unsetenv("LD_PRELOAD");
-
-      ram =  exec("cat /proc/meminfo | grep 'MemTotal' | awk '{print $2}'");
-      trim(ram);
-      cpu =  exec("cat /proc/cpuinfo | grep 'model name' | tail -n1 | sed 's/^.*: //' | sed 's/([^)]*)/()/g' | tr -d '(/)'");
-      trim(cpu);
-      kernel = exec("uname -r");
-      trim(kernel);
-      os = exec("cat /etc/*-release | grep 'PRETTY_NAME' | cut -d '=' -f 2-");
-      os.erase(remove(os.begin(), os.end(), '\"' ), os.end());
-      trim(os);
-      cpusched = read_line("/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor");
-
-      const char* mangohud_recursion = getenv("MANGOHUD_RECURSION");
-      if (!mangohud_recursion) {
-         setenv("MANGOHUD_RECURSION", "1", 1);
-         driver = exec("glxinfo -B | grep 'OpenGL version' | sed 's/^.*: //' | sed 's/([^()]*)//g' | tr -s ' '");
-         trim(driver);
-         unsetenv("MANGOHUD_RECURSION");
-      } else {
-         driver = "MangoHud glxinfo recursion detected";
-      }
-
-// Get WINE version
-
-      wineProcess = get_exe_path();
-      auto n = wineProcess.find_last_of('/');
-      string preloader = wineProcess.substr(n + 1);
-      if (preloader == "wine-preloader" || preloader == "wine64-preloader") {
-         // Check if using Proton
-         if (wineProcess.find("/dist/bin/wine") != std::string::npos || wineProcess.find("/files/bin/wine") != std::string::npos) {
-            stringstream ss;
-            ss << dirname((char*)wineProcess.c_str()) << "/../../version";
-            string protonVersion = ss.str();
-            ss.str(""); ss.clear();
-            ss << read_line(protonVersion);
-            std::getline(ss, wineVersion, ' '); // skip first number string
-            std::getline(ss, wineVersion, ' ');
-            trim(wineVersion);
-            string toReplace = "proton-";
-            size_t pos = wineVersion.find(toReplace);
-            if (pos != std::string::npos) {
-               // If found replace
-               wineVersion.replace(pos, toReplace.length(), "Proton ");
-            }
-            else {
-               // If not found insert for non official proton builds
-               wineVersion.insert(0, "Proton ");
-            }
-         }
-         else {
-            char *dir = dirname((char*)wineProcess.c_str());
-            stringstream findVersion;
-            findVersion << "\"" << dir << "/wine\" --version";
-            const char *wine_env = getenv("WINELOADERNOEXEC");
-            if (wine_env)
-               unsetenv("WINELOADERNOEXEC");
-            wineVersion = exec(findVersion.str());
-            std::cout << "WINE VERSION = " << wineVersion << "\n";
-            if (wine_env)
-               setenv("WINELOADERNOEXEC", wine_env, 1);
-         }
-      }
-      else {
-           wineVersion = "";
-      }
-      // check for gamemode and vkbasalt
-      stringstream ss;
-      string line;
-      auto pid = getpid();
-      string path = "/proc/" + to_string(pid) + "/map_files/";
-      auto files = exec("ls " + path);
-      ss << files;
-      while(std::getline(ss, line, '\n')){
-         auto file = path + line;
-         auto sym = read_symlink(file.c_str());
-         if (sym.find("gamemode") != std::string::npos)
-            HUDElements.gamemode_bol = true;
-         if (sym.find("vkbasalt") != std::string::npos)
-            HUDElements.vkbasalt_bol = true;
-         if (HUDElements.gamemode_bol && HUDElements.vkbasalt_bol)
-            break;
-      }
-
-      if (ld_preload)
-         setenv("LD_PRELOAD", ld_preload, 1);
-#ifndef NDEBUG
-      std::cout << "Ram:" << ram << "\n"
-                << "Cpu:" << cpu << "\n"
-                << "Kernel:" << kernel << "\n"
-                << "Os:" << os << "\n"
-                << "Gpu:" << gpu << "\n"
-                << "Driver:" << driver << "\n"
-                << "CPU Scheduler:" << cpusched << std::endl;
-#endif
-#endif
-}
-
 static void snapshot_swapchain_frame(struct swapchain_data *data)
 {
    struct device_data *device_data = data->device;
    struct instance_data *instance_data = device_data->instance;
    update_hud_info(data->sw_stats, instance_data->params, device_data->properties.vendorID);
-   check_keybinds(data->sw_stats, instance_data->params, device_data->properties.vendorID);
-
-   // not currently used
-   // if (instance_data->params.control >= 0) {
-   //    control_client_check(device_data);
-   //    process_control_socket(instance_data);
-   // }
+   check_keybinds(instance_data->params, device_data->properties.vendorID);
+#ifdef __linux__
+   if (instance_data->params.control >= 0) {
+      control_client_check(device_data);
+      process_control_socket(instance_data);
+   }
+#endif
 }
 
 static void compute_swapchain_display(struct swapchain_data *data)
@@ -720,6 +433,9 @@ static void compute_swapchain_display(struct swapchain_data *data)
    struct device_data *device_data = data->device;
    struct instance_data *instance_data = device_data->instance;
 
+   if (instance_data->params.no_display)
+      return;
+
    ImGui::SetCurrentContext(data->imgui_context);
    if (HUDElements.colors.update)
       HUDElements.convert_colors(instance_data->params);
@@ -958,7 +674,7 @@ static void check_fonts(struct swapchain_data* data)
 
    if (params.font_params_hash != data->sw_stats.font_params_hash)
    {
-      std::cerr << "MANGOHUD: recreating font image\n";
+      SPDLOG_DEBUG("Recreating font image");
       VkDescriptorSet desc_set = (VkDescriptorSet)io.Fonts->TexID;
       create_fonts(instance_data->params, data->sw_stats.font1, data->sw_stats.font_text);
       unsigned char* pixels;
@@ -975,14 +691,9 @@ static void check_fonts(struct swapchain_data* data)
          desc_set = create_image_with_desc(data, width, height, VK_FORMAT_R8_UNORM, data->font_image, data->font_mem, data->font_image_view);
 
       io.Fonts->SetTexID((ImTextureID)desc_set);
-
       data->font_uploaded = false;
       data->sw_stats.font_params_hash = params.font_params_hash;
-
-#ifndef NDEBUG
-      std::cerr << "MANGOHUD: Default font tex size: " << width << "x" << height << "px (" << (width*height*1) << " bytes)" << "\n";
-#endif
-
+      SPDLOG_DEBUG("Default font tex size: {}x{}px", width, height);
    }
 }
 
@@ -1049,10 +760,11 @@ static struct overlay_draw *render_swapchain_display(struct swapchain_data *data
                                                      unsigned image_index)
 {
    ImDrawData* draw_data = ImGui::GetDrawData();
-   if (draw_data->TotalVtxCount == 0)
-      return NULL;
-
    struct device_data *device_data = data->device;
+
+   if (!draw_data || draw_data->TotalVtxCount == 0 || device_data->instance->params.no_display)
+      return nullptr;
+
    struct overlay_draw *draw = get_overlay_draw(data);
 
    device_data->vtable.ResetCommandBuffer(draw->command_buffer, 0);
@@ -1744,38 +1456,25 @@ static struct overlay_draw *before_present(struct swapchain_data *swapchain_data
    return draw;
 }
 
-void get_device_name(int32_t vendorID, int32_t deviceID, struct swapchain_stats& sw_stats)
-{
-#ifdef __gnu_linux__
-   string desc = pci_ids[vendorID].second[deviceID].desc;
-   size_t position = desc.find("[");
-   if (position != std::string::npos) {
-      desc = desc.substr(position);
-      string chars = "[]";
-      for (char c: chars)
-         desc.erase(remove(desc.begin(), desc.end(), c), desc.end());
-   }
-   gpu = sw_stats.gpuName = desc;
-   trim(sw_stats.gpuName); trim(gpu);
-#endif
-}
-
 static VkResult overlay_CreateSwapchainKHR(
     VkDevice                                    device,
     const VkSwapchainCreateInfoKHR*             pCreateInfo,
     const VkAllocationCallbacks*                pAllocator,
     VkSwapchainKHR*                             pSwapchain)
 {
+   VkSwapchainCreateInfoKHR createInfo = *pCreateInfo;
+
+   createInfo.imageUsage |= VK_IMAGE_USAGE_COLOR_ATTACHMENT_BIT;
+
    struct device_data *device_data = FIND(struct device_data, device);
    array<VkPresentModeKHR, 4> modes = {VK_PRESENT_MODE_FIFO_RELAXED_KHR,
            VK_PRESENT_MODE_IMMEDIATE_KHR,
            VK_PRESENT_MODE_MAILBOX_KHR,
            VK_PRESENT_MODE_FIFO_KHR};
-
    if (device_data->instance->params.vsync < 4)
-      const_cast<VkSwapchainCreateInfoKHR*> (pCreateInfo)->presentMode = modes[device_data->instance->params.vsync];
+      createInfo.presentMode = modes[device_data->instance->params.vsync];
 
-   VkResult result = device_data->vtable.CreateSwapchainKHR(device, pCreateInfo, pAllocator, pSwapchain);
+   VkResult result = device_data->vtable.CreateSwapchainKHR(device, &createInfo, pAllocator, pSwapchain);
    if (result != VK_SUCCESS) return result;
    struct swapchain_data *swapchain_data = new_swapchain_data(*pSwapchain, device_data);
    setup_swapchain_data(swapchain_data, pCreateInfo);
@@ -1803,45 +1502,18 @@ static VkResult overlay_CreateSwapchainKHR(
 #endif
    else {
       ss << " " << VK_VERSION_MAJOR(prop.driverVersion);
-      if (VK_VERSION_PATCH(prop.driverVersion) >= 99){
-         ss << "." << VK_VERSION_MINOR(prop.driverVersion) + 1;
-         ss << "." << "0";
-      }  else {
-         ss << "." << VK_VERSION_MINOR(prop.driverVersion);
-         ss << "." << VK_VERSION_PATCH(prop.driverVersion);
-      }
-
+      ss << "." << VK_VERSION_MINOR(prop.driverVersion);
+      ss << "." << VK_VERSION_PATCH(prop.driverVersion);
    }
    std::string driverVersion = ss.str();
 
    std::string deviceName = prop.deviceName;
    if (!is_blacklisted()) {
-#ifdef __gnu_linux__
-      parse_pciids();
-      get_device_name(prop.vendorID, prop.deviceID, swapchain_data->sw_stats);
-      init_system_info();
+#ifdef __linux__
+      swapchain_data->sw_stats.gpuName = get_device_name(prop.vendorID, prop.deviceID);
 #endif
-      init_gpu_stats(device_data->properties.vendorID, device_data->instance->params);
    }
-   if(driverProps.driverID == VK_DRIVER_ID_NVIDIA_PROPRIETARY){
-      swapchain_data->sw_stats.driverName = "NVIDIA";
-   }
-   if(driverProps.driverID == VK_DRIVER_ID_AMD_PROPRIETARY)
-      swapchain_data->sw_stats.driverName = "AMDGPU-PRO";
-   if(driverProps.driverID == VK_DRIVER_ID_AMD_OPEN_SOURCE)
-      swapchain_data->sw_stats.driverName = "AMDVLK";
-   if(driverProps.driverID == VK_DRIVER_ID_MESA_RADV){
-      if(deviceName.find("ACO") != std::string::npos){
-         swapchain_data->sw_stats.driverName = "RADV/ACO";
-      } else {
-         swapchain_data->sw_stats.driverName = "RADV";
-      }
-   }
-
-   if (!swapchain_data->sw_stats.driverName.empty())
-      swapchain_data->sw_stats.driverName += driverVersion;
-   else
-      swapchain_data->sw_stats.driverName = prop.deviceName + driverVersion;
+   swapchain_data->sw_stats.driverName = driverProps.driverInfo;
 
    return result;
 }
@@ -1865,17 +1537,6 @@ static void overlay_DestroySwapchainKHR(
    destroy_swapchain_data(swapchain_data);
 }
 
-void FpsLimiter(struct fps_limit& stats){
-   stats.sleepTime = stats.targetFrameTime - (stats.frameStart - stats.frameEnd);
-   if (stats.sleepTime > stats.frameOverhead) {
-      auto adjustedSleep = stats.sleepTime - stats.frameOverhead;
-      this_thread::sleep_for(adjustedSleep);
-      stats.frameOverhead = ((Clock::now() - stats.frameStart) - adjustedSleep);
-      if (stats.frameOverhead > stats.targetFrameTime / 2)
-         stats.frameOverhead = Clock::duration(0);
-   }
-}
-
 static VkResult overlay_QueuePresentKHR(
     VkQueue                                     queue,
     const VkPresentInfoKHR*                     pPresentInfo)
@@ -2119,6 +1780,11 @@ static VkResult overlay_CreateDevice(
 
    if (!is_blacklisted()) {
       device_map_queues(device_data, pCreateInfo);
+#ifdef __linux__
+      gpu = get_device_name(device_data->properties.vendorID, device_data->properties.deviceID);
+      SPDLOG_DEBUG("gpu: {}", gpu);
+#endif
+      init_gpu_stats(device_data->properties.vendorID, device_data->properties.deviceID, device_data->instance->params);
    }
 
    return result;
@@ -2164,7 +1830,9 @@ static VkResult overlay_CreateInstance(
 
       else if(engineName == "mesa zink") {
          engine = ZINK;
+#if !defined(_WIN32)
          MangoHud::GL::sw_stats.engine = ZINK;
+#endif
       }
 
       else if (engineName == "Damavand")
@@ -2200,6 +1868,7 @@ static VkResult overlay_CreateInstance(
    instance_data_map_physical_devices(instance_data, true);
 
    parse_overlay_config(&instance_data->params, getenv("MANGOHUD_CONFIG"));
+   _params = &instance_data->params;
 
    //check for blacklist item in the config file
    for (auto& item : instance_data->params.blacklist) {
@@ -2207,7 +1876,8 @@ static VkResult overlay_CreateInstance(
    }
 
    if (!is_blacklisted()) {
-#ifdef __gnu_linux__
+#ifdef __linux__
+      init_system_info();
       instance_data->notifier.params = &instance_data->params;
       start_notifier(instance_data->notifier);
 #endif
@@ -2240,8 +1910,8 @@ static void overlay_DestroyInstance(
    struct instance_data *instance_data = FIND(struct instance_data, instance);
    instance_data_map_physical_devices(instance_data, false);
    instance_data->vtable.DestroyInstance(instance, pAllocator);
+#ifdef __linux__
    if (!is_blacklisted())
-#ifdef __gnu_linux__
       stop_notifier(instance_data->notifier);
 #endif
    destroy_instance_data(instance_data);
@@ -2249,10 +1919,14 @@ static void overlay_DestroyInstance(
 
 extern "C" VK_LAYER_EXPORT VKAPI_ATTR PFN_vkVoidFunction VKAPI_CALL overlay_GetDeviceProcAddr(VkDevice dev,
                                                                              const char *funcName);
+extern "C" VK_LAYER_EXPORT VKAPI_ATTR PFN_vkVoidFunction VKAPI_CALL overlay_GetInstanceProcAddr(VkInstance instance,
+                                                                               const char *funcName);
+
 static const struct {
    const char *name;
    void *ptr;
 } name_to_funcptr_map[] = {
+   { "vkGetInstanceProcAddr", (void *) overlay_GetInstanceProcAddr },
    { "vkGetDeviceProcAddr", (void *) overlay_GetDeviceProcAddr },
 #define ADD_HOOK(fn) { "vk" # fn, (void *) overlay_ ## fn }
 #define ADD_ALIAS_HOOK(alias, fn) { "vk" # alias, (void *) overlay_ ## fn }
@@ -2297,6 +1971,7 @@ static void *find_ptr(const char *name)
 extern "C" VK_LAYER_EXPORT VKAPI_ATTR PFN_vkVoidFunction VKAPI_CALL overlay_GetDeviceProcAddr(VkDevice dev,
                                                                              const char *funcName)
 {
+   init_spdlog();
    void *ptr = find_ptr(funcName);
    if (ptr) return reinterpret_cast<PFN_vkVoidFunction>(ptr);
 
@@ -2310,6 +1985,7 @@ extern "C" VK_LAYER_EXPORT VKAPI_ATTR PFN_vkVoidFunction VKAPI_CALL overlay_GetD
 extern "C" VK_LAYER_EXPORT VKAPI_ATTR PFN_vkVoidFunction VKAPI_CALL overlay_GetInstanceProcAddr(VkInstance instance,
                                                                                const char *funcName)
 {
+   init_spdlog();
    void *ptr = find_ptr(funcName);
    if (ptr) return reinterpret_cast<PFN_vkVoidFunction>(ptr);
 
